@@ -27,12 +27,12 @@ class BindCollector(diamond.collector.Collector):
         config_help.update({
             'host': "",
             'port': "",
-            'publish': "Available stats: \n"
-            + " - resolver (Per-view resolver and cache statistics) \n"
-            + " - server (Incoming requests and their answers) \n"
-            + " - zonemgmt (Zone management requests/responses)\n"
-            + " - sockets (Socket statistics) \n"
-            + " - memory (Global memory usage) \n",
+            'publish': "Available stats:\n" +
+            " - resolver (Per-view resolver and cache statistics)\n" +
+            " - server (Incoming requests and their answers)\n" +
+            " - zonemgmt (Zone management requests/responses)\n" +
+            " - sockets (Socket statistics)\n" +
+            " - memory (Global memory usage)\n",
             'publish_view_bind': "",
             'publish_view_meta': "",
         })
