@@ -37,12 +37,15 @@ class DarnerCollector(diamond.collector.Collector):
     def get_default_config_help(self):
         config_help = super(DarnerCollector, self).get_default_config_help()
         config_help.update({
-            'publish': "Which rows of 'status' you would like to publish."
-            + " Telnet host port' and type stats and hit enter to see the list"
-            + " of possibilities. Leave unset to publish all.",
-            'hosts': "List of hosts, and ports to collect. Set an alias by "
-            + " prefixing the host:port with alias@",
-            'publish_queues': "Publish queue stats (defaults to True)",
+            'publish':
+                "Which rows of 'status' you would like to publish." +
+                " Telnet host port' and type stats and hit enter to see " +
+                " the list of possibilities. Leave unset to publish all.",
+            'hosts':
+                "List of hosts, and ports to collect. Set an alias by " +
+                " prefixing the host:port with alias@",
+            'publish_queues':
+                "Publish queue stats (defaults to True)",
         })
         return config_help
 
