@@ -13,6 +13,7 @@ with server hardware but usually not available in consumer hardware.
 """
 
 import diamond.collector
+from diamond.collector import str_to_bool
 from subprocess import Popen, PIPE
 import os
 import getpass
@@ -27,7 +28,8 @@ class IPMISensorCollector(diamond.collector.Collector):
             'bin': 'Path to the ipmitool binary',
             'use_sudo': 'Use sudo?',
             'sudo_cmd': 'Path to sudo',
-            'thresholds': 'Collect thresholds as well as reading'
+            'thresholds': 'Collect thresholds as well as reading',
+            'delimiter': 'Parse blanks in sensor names into a delimiter'
         })
         return config_help
 
@@ -42,6 +44,7 @@ class IPMISensorCollector(diamond.collector.Collector):
             'sudo_cmd':         '/usr/bin/sudo',
             'path':             'ipmi.sensors',
             'thresholds':       False,
+            'delimiter':        '.'
         })
         return config
 
@@ -71,14 +74,15 @@ class IPMISensorCollector(diamond.collector.Collector):
         return None
 
     def collect(self):
-        if (not os.access(self.config['bin'], os.X_OK)
-            or (self.config['use_sudo']
-                and not os.access(self.config['sudo_cmd'], os.X_OK))):
+        use_sudo = str_to_bool(self.config['use_sudo'])
+        if ((not os.access(self.config['bin'], os.X_OK) or
+             (use_sudo and
+              not os.access(self.config['sudo_cmd'], os.X_OK)))):
             return False
 
         command = [self.config['bin'], 'sensor']
 
-        if self.config['use_sudo'] and getpass.getuser() != 'root':
+        if use_sudo and getpass.getuser() != 'root':
             command.insert(0, self.config['sudo_cmd'])
 
         p = Popen(command, stdout=PIPE).communicate()[0][:-1]
@@ -87,8 +91,10 @@ class IPMISensorCollector(diamond.collector.Collector):
             data = v.split("|")
             try:
                 # Complex keys are fun!
-                metric_name = data[0].strip().replace(".",
-                                                      "_").replace(" ", ".")
+                metric_name = data[0].strip()
+                metric_name = metric_name.replace(".", "_")
+                metric_name = metric_name.replace(" ",
+                                                  self.config['delimiter'])
                 metrics = []
 
                 # Each sensor line is a column seperated by a | with the
