@@ -23,6 +23,7 @@ from memory_cgroup import MemoryCgroupCollector
 
 
 class MemoryDockerCollector(MemoryCgroupCollector):
+
     def collect(self):
         if docker is None:
             self.log.error('Unable to import docker')
@@ -37,6 +38,7 @@ class MemoryDockerCollector(MemoryCgroupCollector):
     def publish(self, metric_name, value, metric_type):
         for container_id, container_name in self.containers.items():
             metric_name = metric_name.replace(
-                'docker.'+container_id+'.', 'docker.'+container_name+'.')
+                'docker.' + container_id + '.',
+                'docker.' + container_name + '.')
         return super(MemoryDockerCollector, self).publish(
             metric_name, value, metric_type)
