@@ -16,9 +16,13 @@
 """
 
 import diamond.collector
-import xml.etree.ElementTree as ET
 from diamond.metric import Metric
 
+try:
+    import xml.etree.ElementTree as ET
+except ImportError:
+    import cElementTree as ET
+
 try:
     from netappsdk.NaServer import *
     from netappsdk.NaElement import *
@@ -29,7 +33,7 @@ except ImportError:
 __author__ = 'peter@phyn3t.com'
 
 
-class netapp_inodeCol():
+class netapp_inodeCol(object):
     """ Our netapp_inode Collector
     """
 
@@ -121,42 +125,3 @@ class netapp_inode(diamond.collector.Collector):
 
         netapp_inodeCol(device, ip, user, password, prefix, pm)
         self.running.remove(device)
-
-    def get_schedule(self):
-        """ Override Collector.get_schedule
-
-           We override collector.get_schedule so we can increase speed
-           by having a task per netapp filer
-
-            return schedule - dictionary with key being className_device
-              value is tuple containing:
-                0(tuple) - object collector method
-                1(tuple) - device, ip, user, password
-                2(int)   - splay, set in diamond.conf
-                3(int)   - interval, set in diamond.conf
-
-        """
-
-        schedule = {}
-
-        if 'devices' in self.config:
-
-            for device in self.config['devices']:
-                filer_config = self.config['devices'][device]
-                task_name = '_'.join([self.__class__.__name__, device])
-
-                if task_name in schedule:
-                    raise KeyError('Duplicate netapp filer scheduled')
-
-                schedule[task_name] = (
-                    self.collect,
-                    (device,
-                     filer_config['ip'],
-                     filer_config['user'],
-                     filer_config['password']),
-                    int(self.config['splay']),
-                    int(self.config['interval']))
-
-                self.log.info("Set up scheduler for %s" % device)
-
-        return schedule
