@@ -16,6 +16,7 @@ Metrics:
 """
 
 import diamond.collector
+from diamond.collector import str_to_bool
 import subprocess
 import re
 
@@ -47,7 +48,7 @@ class OssecCollector(diamond.collector.Collector):
     def collect(self):
         command = [self.config['bin'], '-l']
 
-        if self.config['use_sudo']:
+        if str_to_bool(self.config['use_sudo']):
             command.insert(0, self.config['sudo_cmd'])
 
         try:
