@@ -134,8 +134,9 @@ class TokuMXCollector(diamond.collector.Collector):
                 try:
                     conn.admin.authenticate(user, passwd)
                 except Exception, e:
-                    self.log.error('User auth given, but could not autheticate'
-                                   + ' with host: %s, err: %s' % (host, e))
+                    self.log.error(
+                        'User auth given, but could not autheticate' +
+                        ' with host: %s, err: %s' % (host, e))
                     return{}
 
             serverStatus = conn.db.command('serverStatus')
@@ -172,7 +173,8 @@ class TokuMXCollector(diamond.collector.Collector):
                                        base_prefix + ['opcounters_per_sec'],
                                        self.publish_counter)
         self._publish_dict_with_prefix(data.get('opcountersRepl', {}),
-                                       base_prefix + ['opcountersRepl_per_sec'],
+                                       base_prefix +
+                                       ['opcountersRepl_per_sec'],
                                        self.publish_counter)
         self._publish_dict_with_prefix(data.get('network', {}),
                                        base_prefix + ['network_per_sec'],
