@@ -18,6 +18,8 @@ class VMStatCollector(diamond.collector.Collector):
 
     PROC = '/proc/vmstat'
     MAX_VALUES = {
+        'pgfault': diamond.collector.MAX_COUNTER,
+        'pgmajfault': diamond.collector.MAX_COUNTER,
         'pgpgin': diamond.collector.MAX_COUNTER,
         'pgpgout': diamond.collector.MAX_COUNTER,
         'pswpin': diamond.collector.MAX_COUNTER,
@@ -44,10 +46,9 @@ class VMStatCollector(diamond.collector.Collector):
         if not os.access(self.PROC, os.R_OK):
             return None
 
-        results = {}
         # open file
         file = open(self.PROC)
-        exp = '^(pgpgin|pgpgout|pswpin|pswpout)\s(\d+)'
+        exp = '^(pgfault|pgmajfault|pgpgin|pgpgout|pswpin|pswpout)\s(\d+)'
         reg = re.compile(exp)
         # Build regex
         for line in file:
@@ -55,12 +56,9 @@ class VMStatCollector(diamond.collector.Collector):
             if match:
                 name = match.group(1)
                 value = match.group(2)
-                results[name] = self.derivative(name,
-                                                int(value),
-                                                self.MAX_VALUES[name])
+                max_value = self.MAX_VALUES[name]
+                derived = self.derivative(name, int(value), max_value)
+                self.publish(name, derived, raw_value=int(value), precision=2)
 
         # Close file
         file.close()
-
-        for key, value in results.items():
-            self.publish(key, value, 2)
